#!/opt/cloudlinux/venv/bin/python3 -bb
# coding=utf-8
#
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENCE.TXT
#
from __future__ import absolute_import
from clcommon import FormattedException


class BaseConfigError(FormattedException):
    pass


class MalformedConfigError(BaseConfigError):
    """
    Error that is raised when config is
    malformed and cannot be read.
    """
    def __init__(self, config_path):
        super(MalformedConfigError, self).__init__(dict(
            message='Config file: {} is corrupted, try to run wizard again '
                    'or contact CloudLinux support.'.format(config_path)
        ))


class NoSuchModule(BaseConfigError):
    """
    Error that is raised when we are trying to get state
    or options for module from config, but it is absent
    """
    def __init__(self, module):
        super(NoSuchModule, self).__init__(dict(
            message='No such module "%(module)s" in config.',
            context=dict(module=module)
        ))


class UnableAcquireLockError(BaseConfigError):
    def __init__(self, error_message):
        super(UnableAcquireLockError, self).__init__(dict(
            message='Unable to acquire lock for config due to error: "%(error)s".',
            context=dict(error=error_message)
        ))
